/*********************************************************************************



Copyright(c) 2005 Analog Devices, Inc. All Rights Reserved. 



This software is proprietary and confidential.  By using this software you agree

to the terms of the associated Analog Devices License Agreement.  



Description:

			 Configures the Power Management and EBIU modules for the 

			 ADSP-BF533 EZ-KIT LITE.

			 

*********************************************************************************/



//#include <PowerDemo.h>
#include "PowerInit.h"



void delay(int count) {
    int i;
   	for(i=0;i<DELAY_COUNT*count;i++) {
   	  asm("NOP;");
   	}
}



/*********************************************************************


	Function:		Init



	Description:	Performs Processor specific initialization



*********************************************************************/

void Init(void)

{

	// configure async memory / flash for 533

	//ezInit(1);



	// Initialize the EBIU module (SDRAM)

	InitSDRAM();

	

	// Initialize the power management module

	InitPower();

	

}



static void InitPower(void)

{

	ADI_PWR_RESULT 	PWRResult;

	ADI_PWR_COMMAND_PAIR ezkit_power[] = {	

		{ ADI_PWR_CMD_SET_PROC_VARIANT, (void*)ADI_PWR_PROC_BF531_OR_BF532  },	// Processor variant

		{ ADI_PWR_CMD_SET_PACKAGE,      (void*)ADI_PWR_PACKAGE_LQFP       	},  // Packaging type of processor

		{ ADI_PWR_CMD_SET_VDDEXT,       (void*)ADI_PWR_VDDEXT_330         	},	// External voltage supply (3.3V)
		{ADI_PWR_CMD_SET_VDDINT,		(void*)ADI_PWR_VLEV_125				},

		{ ADI_PWR_CMD_SET_CLKIN,        (void*)25 /* MHz */             	},  // 25Mhz oscillator connected to CLKIN

		{ ADI_PWR_CMD_END, (void*)0}											// No more commands

	};	



	PWRResult = adi_pwr_Init( ezkit_power );

	if ((PWRResult != ADI_PWR_RESULT_SUCCESS) && (PWRResult != ADI_PWR_RESULT_CALL_IGNORED)) {

		int k;	
		for(k=0;k<0x0005;k++) {
	 	  	*pFIO_FLAG_S = 0xFFFF;
			delay(50);
	  	  	*pFIO_FLAG_C = 0xFFFF;
			delay(50);
		}
	}
	adi_pwr_SetMaxFreqForVolt( ADI_PWR_VLEV_125 );

}



#define DO_NOT_CHANGE_MMR_SETTINGS 0

static ADI_EBIU_SDRAM_BANK_VALUE bank_size =  {0, ADI_EBIU_SDRAM_BANK_32MB};


static void InitSDRAM(void)

{

	ADI_EBIU_RESULT EBIUResult;

	ADI_EBIU_COMMAND_PAIR ezkit_sdram[] = {	

			{ ADI_EBIU_CMD_SET_SDRAM_BANK_SIZE,		(void*)&bank_size                             },

			{ ADI_EBIU_CMD_SET_SDRAM_MODULE, 		(void*)ADI_EBIU_SDRAM_MODULE_MT48LC16M16A2_7E },

			{ ADI_EBIU_CMD_END, 0}

	};

	EBIUResult = adi_ebiu_Init( ezkit_sdram, DO_NOT_CHANGE_MMR_SETTINGS );

	if ((EBIUResult != ADI_EBIU_RESULT_SUCCESS) && (EBIUResult != ADI_EBIU_RESULT_CALL_IGNORED)) {

		int k;	
		for(k=0;k<0x0005;k++) {
	 	  	*pFIO_FLAG_S = 0xFFFF;
			delay(50);
	  	  	*pFIO_FLAG_C = 0xFFFF;
			delay(50);
		}


	}

}







